@@ -4,8 +4,8 @@ import re, json, os
 # a search for anything none-alphanumeric and not an underscore
 _AN = re.compile('[^\w_]')
 
-from skipole.skilift import fromjson, off_piste, set_label, versions, lib_list, labels
-from skipole import FailPage, ValidateError, ServerError, GoTo
+from ....skilift import fromjson, off_piste, set_label, versions, lib_list, labels
+from ... import FailPage, ValidateError, ServerError, GoTo
 
 from .. import utils, css_styles
 
@@ -405,10 +405,10 @@ def set_javascript_to_cdn(skicall):
     editedprojname = call_data['editedprojname']
 
     skipole_version, project_version = versions(editedprojname)
-    # get this to point to https://cdn.jsdelivr.net/gh/bernie-skipole/skipole@5/skipole/templates/skis/static/js/
+    # get this to point to https://cdn.jsdelivr.net/gh/bernie-skipole/skipole@5/skipole/skis/static/js/
     # so primary version number is used
     version_numbers = skipole_version.split(".")
-    starthttp =  "https://cdn.jsdelivr.net/gh/bernie-skipole/skipole@" + version_numbers[0] + "/skipole/templates/skis/static/js/"
+    starthttp =  "https://cdn.jsdelivr.net/gh/bernie-skipole/skipole@" + version_numbers[0] + "/skipole/skis/static/js/"
     liblabels = lib_list()
     projlabels = labels(editedprojname)
     try:
